/* Bitset vectors.

   Copyright (C) 2002, 2004, 2009-2015, 2018 Free Software Foundation,
   Inc.

   Contributed by Akim Demaille (akim@freefriends.org).

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

#ifndef _BITSETV_PRINT_H
#define _BITSETV_PRINT_H

#include "bitsetv.h"

/* Dump vector of bitsets as a matrix.  */
void bitsetv_matrix_dump (FILE *, const char *, bitsetv);

#endif  /* _BITSETV_H  */
